# Copyright (c) 2010 by Yaco Sistemas
#
# This file is part of Merengue.
#
# Merengue is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Merengue is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Merengue.  If not, see <http://www.gnu.org/licenses/>.

from django.conf.urls.defaults import patterns, url

PREFIX_DOC = 'info'

urlpatterns = patterns('plugins.microsite.views',
    url(r'^(?P<microsite_slug>[\w-]+)/$', 'microsite_view', name='microsite_view'),
    url(r'^(?P<microsite_slug>[\w-]+)/%s/(?P<doc_id>\d+)/(?P<doc_slug>[\w-]+)/$' % PREFIX_DOC, 'document_microsite_view', name='document_microsite_view'),
    url(r'^(?P<microsite_slug>[\w-]+)/(?P<url>.*)$', 'microsite_url', name='microsite_url'),
)
